# LiveReload X

This is a [folk][fork] of [lepture/python-livereload][origin] for fixing `forever` delay [issue#125][issue#125]. 
Future features are not guaranteed.

Reload webpages on changes, without hitting refresh in your browser.

[origin]: https://github.com/lepture/python-livereload
[fork]: https://github.com/tuanchauict/python-livereload
[issue#125]: https://github.com/lepture/python-livereload/issues/125

## Installation

<!-- start install -->

LiveReload is for web developers who know Python. It is available on [PyPI].

```
$ pip install livereloadx
```

[pypi]: https://pypi.python.org/pypi/livereload

<!-- end install -->

## Documentation

[LiveReload's documentation is hosted on ReadTheDocs][docs].

[docs]: https://livereload.readthedocs.io/en/latest/

## Security Report

To report a security vulnerability, please use the [Tidelift security contact].
Tidelift will coordinate the fix and disclosure.

[tidelift security contact]: https://tidelift.com/security
